aboutsummaryrefslogtreecommitdiffstats
path: root/common/rfb/SSecurityVeNCrypt.cxx
diff options
context:
space:
mode:
authorPierre Ossman <ossman@cendio.se>2022-09-10 13:19:41 +0200
committerPierre Ossman <ossman@cendio.se>2023-02-01 21:17:12 +0100
commit6881c895ab317bd302addac5f228b7367136017f (patch)
tree18d1119f59209147d97e873c3dbc9be36e429aaf /common/rfb/SSecurityVeNCrypt.cxx
parentbaca73d03217a1c219d9c4f024ffcd39f85fd322 (diff)
downloadtigervnc-6881c895ab317bd302addac5f228b7367136017f.tar.gz
tigervnc-6881c895ab317bd302addac5f228b7367136017f.zip
Use stdint types
Avoid having our own custom stuff and instead use the modern, standard types, for familiarity.
Diffstat (limited to 'common/rfb/SSecurityVeNCrypt.cxx')
-rw-r--r--common/rfb/SSecurityVeNCrypt.cxx12
1 files changed, 6 insertions, 6 deletions
diff --git a/common/rfb/SSecurityVeNCrypt.cxx b/common/rfb/SSecurityVeNCrypt.cxx
index 70d50d20..c126d82f 100644
--- a/common/rfb/SSecurityVeNCrypt.cxx
+++ b/common/rfb/SSecurityVeNCrypt.cxx
@@ -64,7 +64,7 @@ bool SSecurityVeNCrypt::processMsg()
{
rdr::InStream* is = sc->getInStream();
rdr::OutStream* os = sc->getOutStream();
- rdr::U8 i;
+ uint8_t i;
/* VeNCrypt initialization */
@@ -93,7 +93,7 @@ bool SSecurityVeNCrypt::processMsg()
haveRecvdMinorVersion = true;
/* WORD value with major version in upper 8 bits and minor version in lower 8 bits */
- U16 Version = (((U16)majorVersion) << 8) | ((U16)minorVersion);
+ uint16_t Version = (((uint16_t)majorVersion) << 8) | ((uint16_t)minorVersion);
switch (Version) {
case 0x0000: /* 0.0 - The client cannot support us! */
@@ -115,16 +115,16 @@ bool SSecurityVeNCrypt::processMsg()
}
/*
* send number of supported VeNCrypt authentication types (U8) followed
* by authentication types (U32s)
*/
if (!haveSentTypes) {
- list<U32> listSubTypes;
+ list<uint32_t> listSubTypes;
listSubTypes = security->GetEnabledExtSecTypes();
numTypes = listSubTypes.size();
- subTypes = new U32[numTypes];
+ subTypes = new uint32_t[numTypes];
for (i = 0; i < numTypes; i++) {
subTypes[i] = listSubTypes.front();
@@ -115,16 +115,16 @@ bool SSecurityVeNCrypt::processMsg()
}
/*
- * send number of supported VeNCrypt authentication types (U8) followed
- * by authentication types (U32s)
+ * send number of supported VeNCrypt authentication types (uint8_t)
+ * followed by authentication types (uint32_t:s)
*/
if (!haveSentTypes) {